==> 23.09.zip: win11x-playbook/README.md <==
# ReviOS Playbook
[![Releases](https://img.shields.io/github/v/release/meetrevision/playbook.svg)](https://github.com/meetrevision/playbook/releases)
[![License](https://img.shields.io/static/v1?label=LICENSE&message=CC%20BY-NC-SA&logo=creativecommons)](https://creativecommons.org/licenses/by-nc-sa/4.0/)
<a href="https://www.buymeacoffee.com/meetrevision" target="_blank"><img src="https://www.buymeacoffee.com/assets/img/custom_images/orange_img.png" alt="Buy Me A Coffee" height="20px"></a>
<br>

ReviOS is a customized version of Windows, designed to be lightweight, stable, and focused on improving performance, privacy and compatibility. It aspires to re-create what Windows as an operating system should have been - easy and simple. Now compatible with [AME Wizard](https://ameliorated.io).

## Features

- Easy to use, just drag and drop the playbook into [AME Wizard](https://ameliorated.io)
- Removes bloatware and unnecessary system components
- Optimizes your system for performance and improved privacy
- Integrates the [Revision Tool](https://github.com/meetrevision/revision-tool) to customize your system further

For more detailed information, see our documentation [here](https://www.revi.cc/docs/faq/before/features).

## System Requirements

- Windows 10 21H2 `19044` (LTSC)
- Windows 10 22H2 `19045`
- Windows 11 22H2 `22621`

Any other build **is not** supported by Revision.

## Getting Started

To use ReviOS Playbook on your computer, follow these steps:

1. Download [AME Wizard](https://ameliorated.io) and our playbook from [releases](https://github.com/meetrevision/playbook/releases)
2. Run the AME Wizard
3. Drag and drop the downloaded playbook into the drag box
4. Follow the on-screen instructions

## Documentation

See our documentation for more information:

- [Playbook](https://www.revi.cc/docs/playbook)
- [Frequently Asked Questions](https://www.revi.cc/docs/faq)
- [Features](https://www.revi.cc/docs/faq/before/features)

## License

ReviOS Playbook is licensed under [Attribution-NonCommercial-ShareAlike 4.0 International](https://creativecommons.org/licenses/by-nc-sa/4.0/).

==> 23.10.zip: win11x-playbook/README.md <==
# ReviOS Playbook
[![Releases](https://img.shields.io/github/v/release/meetrevision/playbook.svg)](https://github.com/meetrevision/playbook/releases)
[![License](https://img.shields.io/static/v1?label=LICENSE&message=CC%20BY-NC-SA&logo=creativecommons)](https://creativecommons.org/licenses/by-nc-sa/4.0/)
<a href="https://www.buymeacoffee.com/meetrevision" target="_blank"><img src="https://www.buymeacoffee.com/assets/img/custom_images/orange_img.png" alt="Buy Me A Coffee" height="20px"></a>
<br>

ReviOS is a customized version of Windows, designed to be lightweight, stable, and focused on improving performance, privacy and compatibility. It aspires to re-create what Windows as an operating system should have been - easy and simple. Now compatible with [AME Wizard](https://ameliorated.io).

## Features

- Easy to use, just drag and drop the playbook into [AME Wizard](https://ameliorated.io)
- Removes bloatware and unnecessary system components
- Optimizes your system for performance and improved privacy
- Integrates the [Revision Tool](https://github.com/meetrevision/revision-tool) to customize your system further

For more detailed information, see our documentation [here](https://www.revi.cc/docs/faq/before/features).

## System Requirements

- Windows 10 21H2 `19044` (LTSC)
- Windows 10 22H2 `19045`
- Windows 11 22H2 `22621`
- Windows 11 23H2 `22631`

Any other build **is not** supported by Revision.

## Getting Started

To use ReviOS Playbook on your computer, follow these steps:

1. Download [AME Wizard](https://ameliorated.io) and our playbook from [releases](https://github.com/meetrevision/playbook/releases)
2. Run the AME Wizard
3. Drag and drop the downloaded playbook into the drag box
4. Follow the on-screen instructions

## Documentation

See our documentation for more information:

- [Playbook](https://www.revi.cc/docs/playbook/general)
- [Installing Windows](https://www.revi.cc/docs/playbook/installstock)
- [Installing & Updating ReviOS](https://www.revi.cc/docs/playbook/installrevi)
- [Frequently Asked Questions](https://www.revi.cc/docs/faq)

## License

ReviOS Playbook is licensed under [Attribution-NonCommercial-ShareAlike 4.0 International](https://creativecommons.org/licenses/by-nc-sa/4.0/).
